.. _changelog:

Changelog
=========


Upgrading From kbarbary/sep
---------------------------

.. toctree::
   :maxdepth: 2

   changes_to_c_api

Full Changelog
--------------

.. toctree::
   :maxdepth: 2

   new_changes
   original_changes
